Structs
- Path
Mapper - Strategies for mapping coverage file paths to repository file paths.
Functions
- auto_
normalize_ issue_ paths - Automatically normalize paths in diagnostics data to be relative.
- auto_
normalize_ paths - Automatically normalize paths in coverage data to be relative.